@@ -1,6 +1,16 @@
 """Base abstract backend class."""
 import abc
-import typing as t
+import sys
+from contextlib import suppress
+from typing import Any, Dict, Optional, Type, overload
+
+from apiclient.types import TResponseBody
+
+# Python 3.7 compatibility
+if sys.version_info >= (3, 8):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
 
 
 class ABCBackend(abc.ABC):
@@ -11,7 +21,7 @@ class ABCBackend(abc.ABC):
     def name(self):
         """Backend should have a name."""
 
-    def __init__(self, client: t.Any = None, timeout: int = None, **_):
+    def __init__(self, client: Any = None, timeout: Optional[int] = None, **_):
         """Initialize the backend."""
 
     def __init_subclass__(cls, *args, **kwargs):
@@ -28,35 +38,44 @@ class ABCBackend(abc.ABC):
     async def shutdown(self):
         """Close the backend."""
 
+    @overload
+    async def request(
+        self,
+        method: str,
+        url: str,
+        *,
+        read_response_body: Literal[True] = True,
+        **options
+    ) -> TResponseBody:
+        ...
+
+    @overload
+    async def request(
+        self, method: str, url: str, *, read_response_body: Literal[False], **options
+    ) -> Any:
+        ...
+
     @abc.abstractmethod
     async def request(
         self,
         method: str,
         url: str,
         *,
-        raise_for_status: bool = True,
         read_response_body: bool = True,
+        raise_for_status: bool = True,
         parse_response_body: bool = True,
         **options
     ):
         """Do http request with the backend."""
 
 
-BACKENDS: t.Dict[str, t.Type[ABCBackend]] = {}
+BACKENDS: Dict[str, Type[ABCBackend]] = {}
 
 
-try:
+with suppress(ImportError):
     from ._httpx import BackendHTTPX
-    assert BackendHTTPX
 
-except ImportError:
-    pass
-
-try:
+with suppress(ImportError):
     from ._aiohttp import BackendAIOHTTP
-    assert BackendAIOHTTP
-
-except ImportError:
-    pass
 
 # pylama: ignore=W0611
